@@ -1,11 +1,23 @@
-context("sec-axis")
-
 x <- exp(seq(log(0.001), log(1000), length.out = 100))
 foo <- data_frame(
   x = x,
   y = x / (1 + x)
 )
 
+test_that("sec_axis checks the user input", {
+  scale <- scale_x_continuous()
+  expect_snapshot_error(set_sec_axis(16, scale))
+  expect_silent(set_sec_axis(~ .^2, scale))
+  secondary <- ggproto(NULL, AxisSecondary, trans = 1:10)
+  expect_snapshot_error(secondary$init(scale))
+
+  p <- ggplot(mtcars) + geom_point(aes(disp, mpg)) + scale_y_continuous(sec.axis = ~sin(.))
+  expect_snapshot_error(ggplot_build(p))
+
+  p <- ggplot(mtcars) + geom_point(aes(disp, mpg)) + scale_y_continuous(sec.axis = ~sin(./100))
+  expect_silent(ggplot_build(p))
+})
+
 test_that("dup_axis() works", {
   p <- ggplot(foo, aes(x, y)) +
     geom_point() +
@@ -230,7 +242,7 @@ test_that("sec_axis() respects custom transformations", {
   expect_doppelganger(
     "sec_axis, custom transform",
     ggplot(dat, aes(x = x, y = y)) +
-      geom_line(size = 1, na.rm = T) +
+      geom_line(linewidth = 1, na.rm = T) +
       scale_y_continuous(
         trans =
           magnify_trans_log(interval_low = 0.5, interval_high = 1, reducer = 0.5, reducer2 = 8), breaks =
